## 0.0.37

This new version introduces the GitPython dependency to the project, allowing for Git operations within the project.

### New Features

- GitPython dependency added to both environment.yml and pyproject.toml files to support Git operations within the project (aa6140) (Eric Ma)

### Bug Fixes

- None in this release

### Deprecations

- None in this release
